# ruff: noqa: E402      # Allow using imports at middle of the file

import sys

bl_info = {
    "name": "Solstice Toolbox",
    "blender": (3, 5, 0),
    "category": "Misc",
}

# Test if the libraries are already loaded
# This is useful for reloading the addon during development

if any(map(lambda x: x.startswith("solstice."), sys.modules.keys())):
    # Purge any existing modules with 'solstice.' prefix
    for module_name in list(sys.modules.keys()):
        if module_name.startswith("solstice."):
            del sys.modules[module_name]


# from .align_island import AlignIsland
from .export_constraint import ExportConstraint
from .mirror_mesh import MirrorMeshOperator
import bpy


def uv_menu_func(self, context):
    self.layout.separator()
    self.layout.label(text="Solstice Toolbox", icon="PLUGIN")
    # self.layout.operator(AlignIsland.bl_idname)


def bone_menu_func(self, context):
    self.layout.separator()
    self.layout.label(text="Solstice Toolbox", icon="PLUGIN")
    self.layout.operator(ExportConstraint.bl_idname)


def mirror_menu_func(self, context):
    self.layout.separator()
    self.layout.label(text="Solstice Toolbox", icon="PLUGIN")
    self.layout.operator(MirrorMeshOperator.bl_idname)


def register():
    # bpy.utils.register_class(AlignIsland)
    bpy.utils.register_class(MirrorMeshOperator)
    bpy.utils.register_class(ExportConstraint)
    bpy.types.IMAGE_MT_uvs.append(uv_menu_func)
    bpy.types.VIEW3D_MT_object.append(bone_menu_func)
    bpy.types.VIEW3D_MT_edit_mesh.append(mirror_menu_func)


def unregister():
    bpy.types.IMAGE_MT_uvs.remove(uv_menu_func)
    bpy.types.VIEW3D_MT_object.remove(bone_menu_func)
    bpy.types.VIEW3D_MT_edit_mesh.remove(mirror_menu_func)

    # bpy.utils.unregister_class(AlignIsland)
    bpy.utils.unregister_class(ExportConstraint)
    bpy.utils.unregister_class(MirrorMeshOperator)


if __name__ == "__main__":
    register()
